@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -341,7 +341,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def create_job(
         self,
-        request: jobs.CreateJobRequest = None,
+        request: Union[jobs.CreateJobRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -356,7 +356,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         will always start in ``us-central1``.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.CreateJobRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.CreateJobRequest, dict]):
                 The request object. Request to create a Cloud Dataflow
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -391,7 +391,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def get_job(
         self,
-        request: jobs.GetJobRequest = None,
+        request: Union[jobs.GetJobRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -406,7 +406,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         get the state of jobs that are running in ``us-central1``.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.GetJobRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.GetJobRequest, dict]):
                 The request object. Request to get the state of a Cloud
                 Dataflow job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -441,7 +441,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def update_job(
         self,
-        request: jobs.UpdateJobRequest = None,
+        request: Union[jobs.UpdateJobRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -457,7 +457,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         ``us-central1``.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.UpdateJobRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.UpdateJobRequest, dict]):
                 The request object. Request to update a Cloud Dataflow
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -492,7 +492,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def list_jobs(
         self,
-        request: jobs.ListJobsRequest = None,
+        request: Union[jobs.ListJobsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -509,7 +509,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         running in ``us-central1``.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.ListJobsRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]):
                 The request object. Request to list Cloud Dataflow jobs.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -559,7 +559,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def aggregated_list_jobs(
         self,
-        request: jobs.ListJobsRequest = None,
+        request: Union[jobs.ListJobsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -568,7 +568,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         r"""List the jobs of a project across all regions.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.ListJobsRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.ListJobsRequest, dict]):
                 The request object. Request to list Cloud Dataflow jobs.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -618,7 +618,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def check_active_jobs(
         self,
-        request: jobs.CheckActiveJobsRequest = None,
+        request: Union[jobs.CheckActiveJobsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -628,7 +628,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         project across all regions.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.CheckActiveJobsRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.CheckActiveJobsRequest, dict]):
                 The request object. Request to check is active jobs
                 exists for a project
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -661,7 +661,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
 
     def snapshot_job(
         self,
-        request: jobs.SnapshotJobRequest = None,
+        request: Union[jobs.SnapshotJobRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -670,7 +670,7 @@ class JobsV1Beta3Client(metaclass=JobsV1Beta3ClientMeta):
         r"""Snapshot the state of a streaming job.
 
         Args:
-            request (google.cloud.dataflow_v1beta3.types.SnapshotJobRequest):
+            request (Union[google.cloud.dataflow_v1beta3.types.SnapshotJobRequest, dict]):
                 The request object. Request to create a snapshot of a
                 job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
